============
pyart.aux_io
============

Input/Output routines.

.. automodule:: pyart.aux_io.gamic_hdf5
.. automodule:: pyart.aux_io.odim_h5
.. automodule:: pyart.aux_io.pattern
.. automodule:: pyart.aux_io.radx
